package com.qihoo.security.services;

import com.qihoo.security.services.ScanProgress;
import com.qihoo.security.services.ScanResult;

/**
 * 杀毒引擎扫描的回调接口。
 * @author zhangxu
 */
interface IScanCallback
{
	/** 杀毒引擎初始化完成之后调用此接口通知调用者。调用者需要在调用 init() 之前先调用 registerCallback() 才能接收到此事件。*/
	void onReady();
	
	/**
	 * 每完成一个扫描，都会通过此接口通知调用者。
	 * @param item 当前的扫描结果
	 * @param progress	当前进度
	 * @param total	要扫描的总数，progress/total 就是进度百分比
	 */
	void onProgress(in ScanProgress progress);
	
	/**
	 * 队列里所有的样本都扫描完毕之后调用此接口通知调用者。
	 *
	 * @param pendingResults 扫描结束时，如果还有尚未通过 onProgress() 接口通知调用者的结果，在这里最后一次性全部返回给调用者。
	 * @param hasMore 由于 Android Binder 的限制，一次不能传递太多的数据，所以如果 pendingResults 太多，就分几次调用 onFinished() 方法，hasMore 表示后续还有调用
	 */
	void onFinished(in List<ScanResult> pendingResults, in boolean hasMore);
	
	/** 扫描过程被人为取消之后，会调用 onStop() 方法通知调用者。*/
	void onStop();
	
	/**
	 * 引擎出现错误时调用此方法。注意，由于 QVSSDK 里包含了多个引擎，单个引擎出现问题不影响其它引擎，扫描还会继续，onError() 方法只是通知调用者有错误发生。
	 * @param engineId 出错的引擎ID
	 * @prarm filename 出错时扫描的文件全路径
	 * @param errorMsg 错误提示（捕获的 Exception 的 Message）
	 */
	void onError(in int engineId, in String filename, in String errorMsg);
}