package com.qihoo360.mobilesafe.core.service;

import com.qihoo360.mobilesafe.core.service.ISysProcessCallBack;
import com.qihoo360.mobilesafe.service.ProcessInfo;
import com.qihoo360.mobilesafe.service.KillBean;

interface ISysProcessClear {
   
    /**
     * 注册回调接口
     */
    void registerCallback(ISysProcessCallback callback);

    /**
     * 反注册回调接口
     */
    void unRegisterCallback(ISysProcessCallback callback);

    /**
     * 开始加载进程列表
     * @param isResultContainsRecommendLeaving 结果是否包含建议保留(false,直接返回建议清理)
     */
    oneway void startLoadProcessList(boolean isResultContainsRecommendLeaving) ;
    
    /**
     * 强制加载进程列表并且不考虑保护期
     * @param isResultContainsRecommendLeaving 结果是否包含建议保留(false,直接返回建议清理)
     */
    void forceLoadProcessList(boolean isResultContainsRecommendLeaving) ;
    
    
    /**
     * 一键清理
     */
    void oneKeyClear();
    
    /**
     * 一键清理
     *建议清理+建议保留的
     * @param extraList  建议保留的
     */
    void oneKeyClearWithExtra(in List<KillBean> extraList);

    /**
     * 杀进程列表
     * @param packageList 清理的列表，这里可能是建议清理或者建议保留的
     */
    void startKillProcessList(in List<KillBean> packageList);
    
	/**
     * 获取运行中白名单列表
     */
    List<ProcessInfo> getRunningWhiteList();
     
    /**
     * 获取总的白名单列表
     */
    List<String> getWhiteList();
    
     /**
     * 获取加速的配置文件白名单列表
     */
    List<String> getConfigWhiteList();
    
    
    /**
     *  获取加速的配置文件，不建议清理的列表
     */
    List<String> getConfigRecommentNoKill();
    
    
    /**
     * 获取隐藏程序列表
     */
    List<String> getHideList();
    
    /**
     * 设置用户白名单
     */    
    void setUserWhiteList(String packageName, boolean isWhiteList);
    
    /**
     * 保存用户白名单
     */    
    void saveUserWhiteList();
        
    /**
     * 重新加载配置信息，用于下载升级新配置文件后调用
     */
    void reloadConfig();
    
    /**
     * 是否在保护期最优
     */
    boolean isProtectionPeriodExcellent();
    
     /**
     * 是否时间在保护期
     */
    boolean isProtectionPeriod();
    
    /**
     * 返回自启白名单
     */
    List<String> getAutoRunWhiteListFinish();
    
    /**
     * 返回最近一次内存加速的时间
     */
    long getLastMemoryClearTime();

}